@@ -40,11 +40,12 @@ def collect_runtime_data() -> dict:
         'client_name': 'dcyd',
         'client_version': dcyd.__version__,
         'client_language': 'python',
-        'protocol_version': '1.0',
+        'protocol_name': 'client-log',
+        'protocol_version': '2.0',
         'project_id': project_id,
         'instance_id': instance_id,
-        'process_id': os.getpid(),
-        'thread_id': threading.get_ident(),
+        'process_id': str(os.getpid()),
+        'thread_id': str(threading.get_ident()),
     }
 
 
