@@ -9,8 +9,8 @@ import tempfile
 import google.cloud.logging
 import requests
 
-import dcyd.utils as utils
 import dcyd.gcl_patch as gcl_patch
+import dcyd.utils as utils
 
 
 class ExtractMsgFormatter(logging.Formatter):
@@ -74,7 +74,7 @@ def get_gcp_logger() -> logging.Logger:
     )
     handler.setFormatter(ExtractMsgFormatter())
 
-    logger = logging.getLogger()
+    logger = logging.getLogger('mpm-client-log')
     logger.setLevel(logging.NOTSET)
     logger.addHandler(handler)
     return logger
