@@ -111,4 +111,4 @@ def base64_pickle(obj):
 
 
 def api_url(path='') -> str:
-    return os.getenv('DCYD_API_BASE', 'https://api.dcyd.io') + '/' + path
+    return os.getenv('DCYD_API_BASE', 'https://api.dcyd.io') + path
